==> nextcloud-25.0.12.tgz: nextcloud/apps/logreader/l10n/gl.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Rexistrando",
    "Log Reader" : "Lector de rexistros",
    "A log reader for Nextcloud" : "Un lector de rexistros para Nextcloud",
    "Log reader for Nextcloud" : "Lector de rexistros para Nextcloud",
    "Log reader" : "Lector de rexistros",
    "Open log reader settings" : "Abrir os axustes do lector de rexistros",
    "Log reader settings" : "Axustes do lector de rexistros",
    "Currently the log file {file} is shown" : "Agora amosase o ficheiro de rexistro {file}",
    "Show server log" : "Amosar o rexistro do servidor",
    "Live view is disabled" : "A vista en directo está desactivada",
    "No log file" : "Non hai ficheiro de rexistro",
    "File-based logging must be enabled to access logs from the Web UI." : "Para acceder aos rexistros dende a IU web ten que estar activado o rexistro baseado en ficheiros.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se cree que se trata dun erro, verifique o axuste {setting} na súa configuración {config} e consulte o Manual de administración de Nextcloud.",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "No app in context" : "Non hai ningunha aplicación no contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar a entrada sen procesar",
    "Copy formatted entry" : "Copiar a entrada con formato",
    "Hide exception details" : "Agochar os detalles da excepción",
    "View exception details" : "Ver os detalles da excepción",
    "Raw log entry" : "Entrada do rexistro sen procesar",
    "Log entry successfully copied" : "A entrada do rexistro copiouse correctamente",
    "Search log entries" : "Buscar entradas do rexistro",
    "Caused by {exception}" : "Causado por {exception}",
    "line {line}" : "liña {line}",
    "Filter log levels" : "Filtrar os niveis do rexistro",
    "Time format" : "Formato horario",
    "Live view" : "Vista en directo",
    "Download / Upload logs" : "Descargar / enviar rexistros",
    "Download logs" : "Descargar rexistros",
    "Show local log file" : "Amosar o ficheiro de rexistro local",
    "Upload local log file to be displayed" : "Enviar  o ficheiro de rexistro local para amosalo",
    "Raw data" : "Datos sen procesar",
    "Local time" : "Hora local",
    "UTC time" : "Hora UTC",
    "Time format used for displaying the timestamp" : "Formato de hora usado para amosar a marca de tempo",
    "(Local log files only support the \"raw\" time format)" : "(Os ficheiros de rexistro locais só admiten o formato de hora «sen procesar»).",
    "Could not change date time format." : "Non foi posíbel cambiar o formato da data e hora.",
    "Polling is disabled because server is not configured to log to file" : "A enquisa está desactivada porque o servidor non está configurado para rexistrar no ficheiro",
    "Polling (live view)" : "Enquisa (vista en directo)",
    "Could not change live view setting." : "Non foi posíbel cambiar o axuste da vista en directo.",
    "Filter logging levels" : "Filtrar os niveis do rexistro",
    "Could not set logging levels to show" : "Non foi posíbel estabelecer os niveis do rexistro para amosar",
    "Application" : "Aplicación",
    "Message" : "Mensaxe",
    "Log entry actions" : "Accións de entrada no rexistro",
    "Loading older log entries" : "Cargando as entradas do rexistro máis antigas",
    "No older log entries available" : "Non hai entradas de rexistro máis antigas dispoñíbeis",
    "Collapse row" : "Contraer fila",
    "Expand row" : "Estender a fila",
    "Show details" : "Amosar os detalles",
    "Debug" : "Depurar",
    "Info" : "Información",
    "Warning" : "Advertencia",
    "Error" : "Erro",
    "Fatal" : "Fatal",
    "Could not fetch new log entries (server unavailable)" : "Non foi posíbel recuperar as novas entradas do rexistro (o servidor non está dispoñíbel)",
    "Could not fetch new entries" : "Non foi posíbel recuperar as novas entradas",
    "Could not copy to clipboard, please copy manually:" : "Non foi posíbel copialo no portapapeis, cópieo manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tdnde {address} por {user} ás {time}\n",
    "Error parsing log" : "Produciuse un erro ao analizar o rexistro",
    "Caused by " : "Causado por",
    "Copy" : "Copiar",
    "Copy raw" : "Copia sen procesar",
    "Copy formatted" : "Copia con formato",
    "No server logs" : "Non hai rexistros do servidor",
    "One or more entries are hidden by the log level filter" : "Unha ou máis entradas están agochadas polo filtro de nivel do rexistro",
    "Everything is working fine" : "Todo está a funcionar ben",
    "Load log file" : "Cargar ficheiro de rexistro",
    "Invalid log file" : "Ficheiro de rexistro non válido",
    "Log levels" : "Níveis do registro",
    "Log content" : "Contido do rexistro",
    "Live update" : "Actualización ao vivo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/logreader/l10n/gl.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Rexistrando",
    "Errors in the log" : "Erros no rexistro",
    "No errors in the logs since %s" : "Sen erros nos rexistros dende %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n erro nos rexistros dende %s","%n erros nos rexistros dende %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advertencia nos rexistros dende %s","%n advertencias nos rexistros dende %s"],
    "Log Reader" : "Lector de rexistros",
    "A log reader for Nextcloud" : "Un lector de rexistros para Nextcloud",
    "Log reader for Nextcloud" : "Lector de rexistros para Nextcloud",
    "Log reader" : "Lector de rexistros",
    "Open log reader settings" : "Abrir os axustes do lector de rexistros",
    "Log reader settings" : "Axustes do lector de rexistros",
    "Currently the log file {file} is shown" : "Agora amosase o ficheiro de rexistro {file}",
    "Show server log" : "Amosar o rexistro do servidor",
    "Live view is disabled" : "A vista en directo está desactivada",
    "No log file" : "Non hai ficheiro de rexistro",
    "File-based logging must be enabled to access logs from the Web UI." : "Para acceder aos rexistros dende a IU web ten que estar activado o rexistro baseado en ficheiros.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se cree que se trata dun erro, verifique o axuste {setting} na súa configuración {config} e consulte o Manual de administración de Nextcloud.",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "No app in context" : "Non hai ningunha aplicación no contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar a entrada sen procesar",
    "Copy formatted entry" : "Copiar a entrada con formato",
    "Hide exception details" : "Agochar os detalles da excepción",
    "View exception details" : "Ver os detalles da excepción",
    "Raw log entry" : "Entrada do rexistro sen procesar",
    "Log entry successfully copied" : "A entrada do rexistro copiouse correctamente",
    "Search log entries" : "Buscar entradas do rexistro",
    "Caused by {exception}" : "Causado por {exception}",
    "line {line}" : "liña {line}",
    "Filter log levels" : "Filtrar os niveis do rexistro",
    "Time format" : "Formato horario",
    "Live view" : "Vista en directo",
    "Download / Upload logs" : "Descargar / enviar rexistros",
    "Download logs" : "Descargar rexistros",
    "Show local log file" : "Amosar o ficheiro de rexistro local",
    "Upload local log file to be displayed" : "Enviar  o ficheiro de rexistro local para amosalo",
    "Raw data" : "Datos sen procesar",
    "Local time" : "Hora local",
    "UTC time" : "Hora UTC",
    "Time format used for displaying the timestamp" : "Formato de hora usado para amosar a marca de tempo",
    "(Local log files only support the \"raw\" time format)" : "(Os ficheiros de rexistro locais só admiten o formato de hora «sen procesar»).",
    "Could not change date time format." : "Non foi posíbel cambiar o formato da data e hora.",
    "Polling is disabled because server is not configured to log to file" : "A enquisa está desactivada porque o servidor non está configurado para rexistrar no ficheiro",
    "Polling (live view)" : "Enquisa (vista en directo)",
    "Could not change live view setting." : "Non foi posíbel cambiar o axuste da vista en directo.",
    "Filter logging levels" : "Filtrar os niveis do rexistro",
    "Could not set logging levels to show" : "Non foi posíbel estabelecer os niveis do rexistro para amosar",
    "Application" : "Aplicación",
    "Message" : "Mensaxe",
    "Log entry actions" : "Accións de entrada no rexistro",
    "Loading older log entries" : "Cargando as entradas do rexistro máis antigas",
    "No older log entries available" : "Non hai entradas de rexistro máis antigas dispoñíbeis",
    "Collapse row" : "Contraer fila",
    "Expand row" : "Estender a fila",
    "Show details" : "Amosar os detalles",
    "Debug" : "Depurar",
    "Info" : "Información",
    "Warning" : "Advertencia",
    "Error" : "Erro",
    "Fatal" : "Fatal",
    "Could not fetch new log entries (server unavailable)" : "Non foi posíbel recuperar as novas entradas do rexistro (o servidor non está dispoñíbel)",
    "Could not fetch new entries" : "Non foi posíbel recuperar as novas entradas",
    "Could not copy to clipboard, please copy manually:" : "Non foi posíbel copialo no portapapeis, cópieo manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tdnde {address} por {user} ás {time}\n",
    "Error parsing log" : "Produciuse un erro ao analizar o rexistro",
    "Caused by " : "Causado por",
    "Copy" : "Copiar",
    "Copy raw" : "Copia sen procesar",
    "Copy formatted" : "Copia con formato",
    "No server logs" : "Non hai rexistros do servidor",
    "One or more entries are hidden by the log level filter" : "Unha ou máis entradas están agochadas polo filtro de nivel do rexistro",
    "Everything is working fine" : "Todo está a funcionar ben",
    "Load log file" : "Cargar ficheiro de rexistro",
    "Invalid log file" : "Ficheiro de rexistro non válido",
    "Log levels" : "Níveis do registro",
    "Log content" : "Contido do rexistro",
    "Live update" : "Actualización ao vivo"
},
"nplurals=2; plural=(n != 1);");
